package com.jiuqi.sql.impl;

import com.jiuqi.sql.DBException;
import com.jiuqi.sql.FieldInfo;
import com.jiuqi.sql.OutputRecordBuffer;
import java.io.IOException;
import java.io.OutputStream;
import java.util.Date;

/* loaded from: com_jiuqi_sql_impl.jar:com/jiuqi/sql/impl/DBaseOutputRecordBuffer.class */
public class DBaseOutputRecordBuffer implements OutputRecordBuffer {
    private byte[] buffer;
    private DBaseFileTail strValueList;

    public DBaseOutputRecordBuffer(int recordSize, DBaseFileTail strValueList) {
        this.buffer = new byte[recordSize];
        this.strValueList = strValueList;
    }

    public void writeRecord(OutputStream stream) throws DBException {
        try {
            stream.write(32);
            stream.write(this.buffer);
        } catch (IOException unused) {
            DBException dbe = new DBException();
            throw dbe;
        }
    }

    public void clearBuffer() throws DBException {
    }

    public void writeBoolean(FieldInfo info, boolean value) throws DBException {
        RW.writeBoolean(this.buffer, info.offset, value);
    }

    public void writeDouble(FieldInfo info, double value) throws DBException {
        RW.writeDouble(this.buffer, info.offset, value);
    }

    public void writeInt(FieldInfo info, int value) throws DBException {
        RW.writeInt(this.buffer, info.offset, value);
    }

    public void writeString(FieldInfo info, String value) throws DBException {
        if (value == null) {
            writeNull(info);
        } else {
            RW.writeInt(this.buffer, info.offset, this.strValueList.size());
            this.strValueList.add(value);
        }
    }

    public void writeLong(FieldInfo info, long value) throws DBException {
        RW.writeLong(this.buffer, info.offset, value);
    }

    public void writeDate(FieldInfo info, Date value) throws DBException {
        if (value == null) {
            writeNull(info);
        } else {
            RW.writeDateTime(this.buffer, info.offset, value);
        }
    }

    public void writeNull(FieldInfo info) throws DBException {
        switch (info.type) {
            case 1:
                this.buffer[info.offset] = 32;
                return;
            case 2:
            case 8:
                for (int i = 0; i < 8; i++) {
                    this.buffer[info.offset + i] = 32;
                }
                return;
            case 3:
                for (int i2 = 0; i2 < 8; i2++) {
                    this.buffer[info.offset + i2] = 0;
                }
                return;
            case 4:
            case 7:
            default:
                return;
            case 5:
                for (int i3 = 0; i3 < 4; i3++) {
                    this.buffer[info.offset + i3] = 0;
                }
                return;
            case 6:
                for (int i4 = 0; i4 < 4; i4++) {
                    this.buffer[info.offset + i4] = -1;
                }
                return;
        }
    }
}
